EXPORTS
	??0CMessageAddress@@QAE@XZ @ 1 NONAME ; public: __thiscall CMessageAddress::CMessageAddress(void)
	??0CSendUiIdleMtmLoader@@QAE@AAVCUidNameArray@@AAVCMtmStore@@HPAVCEikHotKeyTable@@H@Z @ 2 NONAME ; public: __thiscall CSendUiIdleMtmLoader::CSendUiIdleMtmLoader(class CUidNameArray &,class CMtmStore &,int,class CEikHotKeyTable *,int)
	??0TSendingCapabilities@@QAE@HHH@Z @ 3 NONAME ; public: __thiscall TSendingCapabilities::TSendingCapabilities(int,int,int)
	??0TSendingCapabilities@@QAE@XZ @ 4 NONAME ; public: __thiscall TSendingCapabilities::TSendingCapabilities(void)
	??1CMessageAddress@@UAE@XZ @ 5 NONAME ; public: virtual __thiscall CMessageAddress::~CMessageAddress(void)
	??1CMessageData@@UAE@XZ @ 6 NONAME ; public: virtual __thiscall CMessageData::~CMessageData(void)
	??1CSendAppUi@@UAE@XZ @ 7 NONAME ; public: virtual __thiscall CSendAppUi::~CSendAppUi(void)
	??1CSendBaseUi@@UAE@XZ @ 8 NONAME ; public: virtual __thiscall CSendBaseUi::~CSendBaseUi(void)
	??1CSendUi@@UAE@XZ @ 9 NONAME ; public: virtual __thiscall CSendUi::~CSendUi(void)
	??1CSendingService@@UAE@XZ @ 10 NONAME ; public: virtual __thiscall CSendingService::~CSendingService(void)
	??1CSendingServiceInfo@@UAE@XZ @ 11 NONAME ; public: virtual __thiscall CSendingServiceInfo::~CSendingServiceInfo(void)
	?AddSendMenuItemL@CSendUi@@QAEXAAVCEikMenuPane@@HHVTSendingCapabilities@@@Z @ 12 NONAME ; public: void __thiscall CSendUi::AddSendMenuItemL(class CEikMenuPane &,int,int,class TSendingCapabilities)
	?AppendAttachmentL@CMessageData@@QAEXABVTDesC16@@@Z @ 13 NONAME ; public: void __thiscall CMessageData::AppendAttachmentL(class TDesC16 const &)
	?AppendBccAddressL@CMessageData@@QAEXABVTDesC16@@0@Z @ 14 NONAME ; public: void __thiscall CMessageData::AppendBccAddressL(class TDesC16 const &,class TDesC16 const &)
	?AppendCcAddressL@CMessageData@@QAEXABVTDesC16@@0@Z @ 15 NONAME ; public: void __thiscall CMessageData::AppendCcAddressL(class TDesC16 const &,class TDesC16 const &)
	?AppendToAddressL@CMessageData@@QAEXABVTDesC16@@0@Z @ 16 NONAME ; public: void __thiscall CMessageData::AppendToAddressL(class TDesC16 const &,class TDesC16 const &)
	?AvailableServicesL@CSendUi@@QAEXAAV?$RPointerArray@VCSendingServiceInfo@@@@VTUid@@@Z @ 17 NONAME ; public: void __thiscall CSendUi::AvailableServicesL(class RPointerArray<class CSendingServiceInfo> &,class TUid)
	?CanAddMtmL@CSendAppUi@@UAEHVTUid@@VTSendingCapabilities@@@Z @ 18 NONAME ; public: virtual int __thiscall CSendAppUi::CanAddMtmL(class TUid,class TSendingCapabilities)
	?CanAddMtmL@CSendBaseUi@@UAEHVTUid@@VTSendingCapabilities@@@Z @ 19 NONAME ; public: virtual int __thiscall CSendBaseUi::CanAddMtmL(class TUid,class TSendingCapabilities)
	?CanSendBioMessage@CSendAppUi@@UAEHVTUid@@@Z @ 20 NONAME ; public: virtual int __thiscall CSendAppUi::CanSendBioMessage(class TUid)
	?CanSendBioMessage@CSendBaseUi@@UAEHVTUid@@@Z @ 21 NONAME ; public: virtual int __thiscall CSendBaseUi::CanSendBioMessage(class TUid)
	?CanSendBioMessage@CSendUi@@QBEHVTUid@@@Z @ 22 NONAME ; public: int __thiscall CSendUi::CanSendBioMessage(class TUid)const 
	?CommandIsValidL@CSendAppUi@@UAEHHVTSendingCapabilities@@PAV?$CArrayFix@VTUid@@@@@Z @ 23 NONAME ; public: virtual int __thiscall CSendAppUi::CommandIsValidL(int,class TSendingCapabilities,class CArrayFix<class TUid> *)
	?CommandIsValidL@CSendBaseUi@@UAEHHVTSendingCapabilities@@PAV?$CArrayFix@VTUid@@@@@Z @ 24 NONAME ; public: virtual int __thiscall CSendBaseUi::CommandIsValidL(int,class TSendingCapabilities,class CArrayFix<class TUid> *)
	?ConstructL@CSendBaseUi@@UAEXHPAVCEikHotKeyTable@@@Z @ 25 NONAME ; public: virtual void __thiscall CSendBaseUi::ConstructL(int,class CEikHotKeyTable *)
	?CopyLC@CSendingServiceInfo@@QBEPAV1@XZ @ 26 NONAME ; public: class CSendingServiceInfo * __thiscall CSendingServiceInfo::CopyLC(void)const 
	?CreateAndSendMessageL@CSendAppUi@@UAEXHPBVCRichText@@PAVMDesC16Array@@VTUid@@11H@Z @ 27 NONAME ; public: virtual void __thiscall CSendAppUi::CreateAndSendMessageL(int,class CRichText const *,class MDesC16Array *,class TUid,class MDesC16Array *,class MDesC16Array *,int)
	?CreateAndSendMessageL@CSendAppUi@@UAEXVTUid@@PBVCRichText@@PAVMDesC16Array@@022H@Z @ 28 NONAME ; public: virtual void __thiscall CSendAppUi::CreateAndSendMessageL(class TUid,class CRichText const *,class MDesC16Array *,class TUid,class MDesC16Array *,class MDesC16Array *,int)
	?CreateAndSendMessageL@CSendBaseUi@@UAEXHPBVCRichText@@PAVMDesC16Array@@VTUid@@11H@Z @ 29 NONAME ; public: virtual void __thiscall CSendBaseUi::CreateAndSendMessageL(int,class CRichText const *,class MDesC16Array *,class TUid,class MDesC16Array *,class MDesC16Array *,int)
	?CreateAndSendMessageL@CSendBaseUi@@UAEXVTUid@@PBVCRichText@@PAVMDesC16Array@@022H@Z @ 30 NONAME ; public: virtual void __thiscall CSendBaseUi::CreateAndSendMessageL(class TUid,class CRichText const *,class MDesC16Array *,class TUid,class MDesC16Array *,class MDesC16Array *,int)
	?CreateAndSendMessageL@CSendUi@@QAEXVTUid@@PBVCMessageData@@0H@Z @ 31 NONAME ; public: void __thiscall CSendUi::CreateAndSendMessageL(class TUid,class CMessageData const *,class TUid,int)
	?CreateAndSendMessagePopupQueryL@CSendAppUi@@UAEXABVTDesC16@@VTSendingCapabilities@@PBVCRichText@@PAVMDesC16Array@@VTUid@@33PAV?$CArrayFix@VTUid@@@@H@Z @ 32 NONAME ; public: virtual void __thiscall CSendAppUi::CreateAndSendMessagePopupQueryL(class TDesC16 const &,class TSendingCapabilities,class CRichText const *,class MDesC16Array *,class TUid,class MDesC16Array *,class MDesC16Array *,class CArrayFix<class TUid> *,int)
	?CreateAndSendMessagePopupQueryL@CSendBaseUi@@UAEXABVTDesC16@@VTSendingCapabilities@@PBVCRichText@@PAVMDesC16Array@@VTUid@@33PAV?$CArrayFix@VTUid@@@@H@Z @ 33 NONAME ; public: virtual void __thiscall CSendBaseUi::CreateAndSendMessagePopupQueryL(class TDesC16 const &,class TSendingCapabilities,class CRichText const *,class MDesC16Array *,class TUid,class MDesC16Array *,class MDesC16Array *,class CArrayFix<class TUid> *,int)
	?CreateAndSendMessagePopupQueryWithSubjectL@CSendAppUi@@UAEXABVTDesC16@@0VTSendingCapabilities@@PBVCRichText@@PAVMDesC16Array@@VTUid@@3333PAV?$CArrayFix@VTUid@@@@H@Z @ 34 NONAME ; public: virtual void __thiscall CSendAppUi::CreateAndSendMessagePopupQueryWithSubjectL(class TDesC16 const &,class TDesC16 const &,class TSendingCapabilities,class CRichText const *,class MDesC16Array *,class TUid,class MDesC16Array *,class MDesC16Array *,class MDesC16Array *,class MDesC16Array *,class CArrayFix<class TUid> *,int)
	?CreateAndSendMessagePopupQueryWithSubjectL@CSendBaseUi@@UAEXABVTDesC16@@0VTSendingCapabilities@@PBVCRichText@@PAVMDesC16Array@@VTUid@@3333PAV?$CArrayFix@VTUid@@@@H@Z @ 35 NONAME ; public: virtual void __thiscall CSendBaseUi::CreateAndSendMessagePopupQueryWithSubjectL(class TDesC16 const &,class TDesC16 const &,class TSendingCapabilities,class CRichText const *,class MDesC16Array *,class TUid,class MDesC16Array *,class MDesC16Array *,class MDesC16Array *,class MDesC16Array *,class CArrayFix<class TUid> *,int)
	?CreateAndSendMessageWithSubjectL@CSendAppUi@@UAEXHABVTDesC16@@PBVCRichText@@PAVMDesC16Array@@VTUid@@2222H@Z @ 36 NONAME ; public: virtual void __thiscall CSendAppUi::CreateAndSendMessageWithSubjectL(int,class TDesC16 const &,class CRichText const *,class MDesC16Array *,class TUid,class MDesC16Array *,class MDesC16Array *,class MDesC16Array *,class MDesC16Array *,int)
	?CreateAndSendMessageWithSubjectL@CSendAppUi@@UAEXVTUid@@ABVTDesC16@@PBVCRichText@@PAVMDesC16Array@@03333H@Z @ 37 NONAME ; public: virtual void __thiscall CSendAppUi::CreateAndSendMessageWithSubjectL(class TUid,class TDesC16 const &,class CRichText const *,class MDesC16Array *,class TUid,class MDesC16Array *,class MDesC16Array *,class MDesC16Array *,class MDesC16Array *,int)
	?CreateAndSendMessageWithSubjectL@CSendBaseUi@@UAEXHABVTDesC16@@PBVCRichText@@PAVMDesC16Array@@VTUid@@2222H@Z @ 38 NONAME ; public: virtual void __thiscall CSendBaseUi::CreateAndSendMessageWithSubjectL(int,class TDesC16 const &,class CRichText const *,class MDesC16Array *,class TUid,class MDesC16Array *,class MDesC16Array *,class MDesC16Array *,class MDesC16Array *,int)
	?CreateAndSendMessageWithSubjectL@CSendBaseUi@@UAEXVTUid@@ABVTDesC16@@PBVCRichText@@PAVMDesC16Array@@03333H@Z @ 39 NONAME ; public: virtual void __thiscall CSendBaseUi::CreateAndSendMessageWithSubjectL(class TUid,class TDesC16 const &,class CRichText const *,class MDesC16Array *,class TUid,class MDesC16Array *,class MDesC16Array *,class MDesC16Array *,class MDesC16Array *,int)
	?CreateDimmableMtmArrayL@CSendAppUi@@UAEPAV?$CArrayFixFlat@VTUid@@@@ABVMDesC16Array@@@Z @ 40 NONAME ; public: virtual class CArrayFixFlat<class TUid> * __thiscall CSendAppUi::CreateDimmableMtmArrayL(class MDesC16Array const &)
	?CreateDimmableMtmArrayL@CSendBaseUi@@UAEPAV?$CArrayFixFlat@VTUid@@@@ABVMDesC16Array@@@Z @ 41 NONAME ; public: virtual class CArrayFixFlat<class TUid> * __thiscall CSendBaseUi::CreateDimmableMtmArrayL(class MDesC16Array const &)
	?DRMConfirmAndFilterProtectedFilesL@CSendUiFileRightsEngine@@QAEHAAVCDesC16ArrayFlat@@VTUid@@@Z @ 42 NONAME ; public: int __thiscall CSendUiFileRightsEngine::DRMConfirmAndFilterProtectedFilesL(class CDesC16ArrayFlat &,class TUid)
	?DisplaySendCascadeMenuL@CSendAppUi@@UAEXAAVCEikMenuPane@@PAV?$CArrayFix@VTUid@@@@@Z @ 43 NONAME ; public: virtual void __thiscall CSendAppUi::DisplaySendCascadeMenuL(class CEikMenuPane &,class CArrayFix<class TUid> *)
	?DisplaySendCascadeMenuL@CSendBaseUi@@UAEXAAVCEikMenuPane@@PAV?$CArrayFix@VTUid@@@@@Z @ 44 NONAME ; public: virtual void __thiscall CSendBaseUi::DisplaySendCascadeMenuL(class CEikMenuPane &,class CArrayFix<class TUid> *)
	?DisplaySendMenuItemL@CSendAppUi@@UAEXAAVCEikMenuPane@@HVTSendingCapabilities@@@Z @ 45 NONAME ; public: virtual void __thiscall CSendAppUi::DisplaySendMenuItemL(class CEikMenuPane &,int,class TSendingCapabilities)
	?DisplaySendMenuItemL@CSendBaseUi@@UAEXAAVCEikMenuPane@@HVTSendingCapabilities@@@Z @ 46 NONAME ; public: virtual void __thiscall CSendBaseUi::DisplaySendMenuItemL(class CEikMenuPane &,int,class TSendingCapabilities)
	?ExpandArrayPropertiesLC@CSendUiFileRightsEngine@@QAEPAVCDesC16ArrayFlat@@ABVMDesC16Array@@@Z @ 47 NONAME ; public: class CDesC16ArrayFlat * __thiscall CSendUiFileRightsEngine::ExpandArrayPropertiesLC(class MDesC16Array const &)
	?FinishL@CSendUiIdleMtmLoader@@QAEXXZ @ 48 NONAME ; public: void __thiscall CSendUiIdleMtmLoader::FinishL(void)
	?MMEFilesSendableViaMMS@CSendUiFileRightsEngine@@QAEHABVMDesC16Array@@@Z @ 49 NONAME ; public: int __thiscall CSendUiFileRightsEngine::MMEFilesSendableViaMMS(class MDesC16Array const &)
	?MMEFilterAndNotifyNonMMSFilesL@CSendUiFileRightsEngine@@QAEHAAVCDesC16ArrayFlat@@VTUid@@@Z @ 50 NONAME ; public: int __thiscall CSendUiFileRightsEngine::MMEFilterAndNotifyNonMMSFilesL(class CDesC16ArrayFlat &,class TUid)
	?MtmCapabilitiesL@CSendAppUi@@UAE?AVTSendingCapabilities@@VTUid@@@Z @ 51 NONAME ; public: virtual class TSendingCapabilities  __thiscall CSendAppUi::MtmCapabilitiesL(class TUid)
	?MtmCapabilitiesL@CSendBaseUi@@UAE?AVTSendingCapabilities@@VTUid@@@Z @ 52 NONAME ; public: virtual class TSendingCapabilities  __thiscall CSendBaseUi::MtmCapabilitiesL(class TUid)
	?MtmForCommand@CSendAppUi@@UAE?AVTUid@@H@Z @ 53 NONAME ; public: virtual class TUid  __thiscall CSendAppUi::MtmForCommand(int)
	?MtmForCommand@CSendBaseUi@@UAE?AVTUid@@H@Z @ 54 NONAME ; public: virtual class TUid  __thiscall CSendBaseUi::MtmForCommand(int)
	?NewL@CMessageData@@SAPAV1@XZ @ 55 NONAME ; public: static class CMessageData * __cdecl CMessageData::NewL(void)
	?NewL@CSendAppUi@@SAPAV1@HPAVCEikHotKeyTable@@@Z @ 56 NONAME ; public: static class CSendAppUi * __cdecl CSendAppUi::NewL(int,class CEikHotKeyTable *)
	?NewL@CSendBaseUi@@SAPAV1@HPAVCEikHotKeyTable@@@Z @ 57 NONAME ; public: static class CSendBaseUi * __cdecl CSendBaseUi::NewL(int,class CEikHotKeyTable *)
	?NewL@CSendUi@@SAPAV1@XZ @ 58 NONAME ; public: static class CSendUi * __cdecl CSendUi::NewL(void)
	?NewL@CSendingService@@SAPAV1@ABVTUid@@@Z @ 59 NONAME ; public: static class CSendingService * __cdecl CSendingService::NewL(class TUid const &)
	?NewL@CSendingServiceInfo@@SAPAV1@XZ @ 60 NONAME ; public: static class CSendingServiceInfo * __cdecl CSendingServiceInfo::NewL(void)
	?NewLC@CSendAppUi@@SAPAV1@HPAVCEikHotKeyTable@@@Z @ 61 NONAME ; public: static class CSendAppUi * __cdecl CSendAppUi::NewLC(int,class CEikHotKeyTable *)
	?NewLC@CSendBaseUi@@SAPAV1@HPAVCEikHotKeyTable@@@Z @ 62 NONAME ; public: static class CSendBaseUi * __cdecl CSendBaseUi::NewLC(int,class CEikHotKeyTable *)
	?NewLC@CSendUi@@SAPAV1@XZ @ 63 NONAME ; public: static class CSendUi * __cdecl CSendUi::NewLC(void)
	?NewLC@CSendUiFileRightsEngine@@SAPAV1@ABVRFs@@ABH@Z @ 64 NONAME ; public: static class CSendUiFileRightsEngine * __cdecl CSendUiFileRightsEngine::NewLC(class RFs const &,int const &)
	?ServiceCapabilitiesL@CSendUi@@QAEHVTUid@@AAVTSendingCapabilities@@@Z @ 65 NONAME ; public: int __thiscall CSendUi::ServiceCapabilitiesL(class TUid,class TSendingCapabilities &)
	?SetAddressL@CMessageAddress@@QAEXABVTDesC16@@@Z @ 66 NONAME ; public: void __thiscall CMessageAddress::SetAddressL(class TDesC16 const &)
	?SetAliasL@CMessageAddress@@QAEXABVTDesC16@@@Z @ 67 NONAME ; public: void __thiscall CMessageAddress::SetAliasL(class TDesC16 const &)
	?SetBodyTextL@CMessageData@@QAEXPBVCRichText@@@Z @ 68 NONAME ; public: void __thiscall CMessageData::SetBodyTextL(class CRichText const *)
	?SetServiceAddressL@CSendingServiceInfo@@QAEXABVTDesC16@@@Z @ 69 NONAME ; public: void __thiscall CSendingServiceInfo::SetServiceAddressL(class TDesC16 const &)
	?SetServiceMenuNameL@CSendingServiceInfo@@QAEXABVTDesC16@@@Z @ 70 NONAME ; public: void __thiscall CSendingServiceInfo::SetServiceMenuNameL(class TDesC16 const &)
	?SetServiceNameL@CSendingServiceInfo@@QAEXABVTDesC16@@@Z @ 71 NONAME ; public: void __thiscall CSendingServiceInfo::SetServiceNameL(class TDesC16 const &)
	?SetSubjectL@CMessageData@@QAEXPBVTDesC16@@@Z @ 72 NONAME ; public: void __thiscall CMessageData::SetSubjectL(class TDesC16 const *)
	?ShowQueryAndSendL@CSendUi@@QAEXPBVCMessageData@@VTSendingCapabilities@@PAV?$CArrayFix@VTUid@@@@VTUid@@HABVTDesC16@@@Z @ 73 NONAME ; public: void __thiscall CSendUi::ShowQueryAndSendL(class CMessageData const *,class TSendingCapabilities,class CArrayFix<class TUid> *,class TUid,int,class TDesC16 const &)
	?ShowSendQueryL@CSendUi@@QAE?AVTUid@@PBVCMessageData@@VTSendingCapabilities@@PAV?$CArrayFix@VTUid@@@@ABVTDesC16@@@Z @ 74 NONAME ; public: class TUid  __thiscall CSendUi::ShowSendQueryL(class CMessageData const *,class TSendingCapabilities,class CArrayFix<class TUid> *,class TDesC16 const &)
	?StartL@CSendUiIdleMtmLoader@@QAEXAAVCMsvSession@@@Z @ 75 NONAME ; public: void __thiscall CSendUiIdleMtmLoader::StartL(class CMsvSession &)
	?ValidateServiceL@CSendUi@@QBEHVTUid@@VTSendingCapabilities@@@Z @ 76 NONAME ; public: int __thiscall CSendUi::ValidateServiceL(class TUid,class TSendingCapabilities)const 

